@@ -17,18 +17,30 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 查询对象存储失败。
+FAILEDOPERATION_COSERROR = 'FailedOperation.CosError'
+
 # 获取上传配置信息错误。
 FAILEDOPERATION_COSPROPERTIESERROR = 'FailedOperation.CosPropertiesError'
 
 # 创建订单失败。
 FAILEDOPERATION_CREATEORDERFAILED = 'FailedOperation.CreateOrderFailed'
 
+# 数据库错误。
+FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'
+
+# 操作失败或者网络超时。
+FAILEDOPERATION_GCSERROR = 'FailedOperation.GcsError'
+
 # 获取VPC网络信息失败。
 FAILEDOPERATION_GETVPCFAILED = 'FailedOperation.GetVpcFailed'
 
 # 备份导入任务锁定失败。
 FAILEDOPERATION_MIGRATIONLOCKERROR = 'FailedOperation.MigrationLockError'
 
+# 不支持此类操作。
+FAILEDOPERATION_NOTSUPPORT = 'FailedOperation.NotSupport'
+
 # 查询订单失败。
 FAILEDOPERATION_QUERYORDERFAILED = 'FailedOperation.QueryOrderFailed'
 
@@ -38,6 +50,9 @@ FAILEDOPERATION_QUERYPRICEFAILED = 'FailedOperation.QueryPriceFailed'
 # 安全组操作失败。
 FAILEDOPERATION_SECURITYGROUPOPERATIONERROR = 'FailedOperation.SecurityGroupOperationError'
 
+# 操作网络失败或者超时。
+FAILEDOPERATION_VPCERROR = 'FailedOperation.VPCError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -161,6 +176,9 @@ INVALIDPARAMETERVALUE_MIGRATIONNAMEISILLEGAL = 'InvalidParameterValue.MigrationN
 # 可选参数[enable, disable]。
 INVALIDPARAMETERVALUE_MODIFYTYPEVALUEINVALID = 'InvalidParameterValue.ModifyTypeValueInvalid'
 
+# 是CVM类型。
+INVALIDPARAMETERVALUE_ONCVMTYPENOTSUPPORTED = 'InvalidParameterValue.OnCvmTypeNotSupported'
+
 # 参数类型错误。
 INVALIDPARAMETERVALUE_PARAMETERTYPEERROR = 'InvalidParameterValue.ParameterTypeError'
 
@@ -212,6 +230,9 @@ RESOURCENOTFOUND_INCREBACKUPMIGRATIONNOTEXIST = 'ResourceNotFound.IncreBackupMig
 # 实例不存在。
 RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
 
+# 参数未找到。
+RESOURCENOTFOUND_PARAMSNOTFOUND = 'ResourceNotFound.ParamsNotFound'
+
 # VPC网络不存在。
 RESOURCENOTFOUND_VPCNOTEXIST = 'ResourceNotFound.VpcNotExist'
 
@@ -251,6 +272,9 @@ UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # 不支持重复操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTREPEAT = 'UnsupportedOperation.NotSupportRepeat'
 
